## Introduction

[![Python Version](https://img.shields.io/badge/python-3.6+-blue.svg?style=flat)](https://pypi.python.org/pypi/sharetop)
[![Pypi Package](https://img.shields.io/pypi/v/sharetop.svg?maxAge=60)](https://pypi.python.org/pypi/sharetop)

[`sharetop`](https://github.com/nrliangxy/sharetop) 为个人或者机构提供准确详细的市场数据。用于获取经济市场相关的股票，基金，期货数据，也可以获取具体的行业数据，例如，猪肉周期相关数据，石油相关数据等。

---

## Installation

- 通过 `pip` 安装

```bash
pip install sharetop
```

- 通过 `pip` 更新

```bash
pip install sharetop --upgrade
```

---

## 使用文档

### 阅读文档

> https://sharetop.top/#/data-api

### 数据列表
*   股票
    * 基础数据
        * A股股票列表
        * 上市公司基本信息
        * 交易日历
        * 股票报告期信息
        * 股票分红信息
        * 股票回购信息
        * 单个或者多个上市公司年报数据
        * 沪深市场股票季报数据
    * 行情
        * 沪深市场整体行情
        * 上市公司K线数据
        * 股票实时数据
        * 龙虎榜数据
* 指数
    * 沪深指数列表
    * 指数成分股列表
    * 全球指数列表
*   市场资金流
    *   历史资金流动数据
    *   实时资金流动数据
    *   资金净流入数据
    *   市场内不同行业，概念，地域，资金净流入数据
*   公募基金 
    *   基金实时估值
    *   不同类型的基金列表
    *   开放基金排行列表
    *   场内交易基金排行
    *   货币型基金排行
    *   香港基金排行
    *   基金基本信息
    *   基金历史净值
    *   基金行业分布信息
    *   基金持仓日期列表
    *   基金同类排行
    *   基金投资类型比重
*   债券
    *   债券基本信息列表
    *   沪深债券实时行情
    *   债券基本信息
*   期货
    *   期货市场的最新行情信息
    *   期货最新交易日成交明细
    *   期货历史行情信息
*   国家数据
    *   国家基本信息列表
*   原油
    *   原油储量
    * 原油产量
    * 原油消费量
    * 原油加工量
    * 原油加工量产能
    * 原油历史价格
* 关联指数
    * 负相关指数
        * 国债收益率和债券价格
            * 国债收益率
                * 历史数据
                * 实时数据
            * 债券基金
                * 场外基金
                * 场内基金
    * 正相关指数
        * 猪肉指数和猪粮比
            * 猪粮比
                * 历史数据(日更新)
            * 发改委猪粮比价预警
                * 历史数据
            * 猪价指数
                * 东财猪肉指数
* 行业数据
    * 汽车销量数据
      * 汽车销量排名（月更新）
    * 猪周期数据
        * 猪肉历史价格和猪粮比（日更新）
    * 世界造船数据
        * 世界造船三大指标
* 宏观指标
  * 电商物流指数
      * 电商物流指数历史数据（月更新）
* 新闻资讯数据
  * 普通新闻数据（分钟级别更新）

## Contact
- 对市场感兴趣的同学可以联系我，对互联网金融感兴趣的同学可以联系我，对市场行业相关数据感兴趣的同学可以联系我，对数据有需求的同学可以联系我。欢迎志同道合的同学联系我
- 关注我们的微信公众号：shareTop，可以获取我们最新的数据更新提醒和行业周期分析

<img src="static/wechat_account.png" width="350">

- 微信：share_top

<img src="static/sharetop.jpg" width="350">


